@@ -9,7 +9,6 @@
  */
 
 #include <cstdlib>
-#include <unistd.h>
 
 #include <QDebug>
 #include <QProcess>
@@ -113,12 +112,6 @@ void ClientManager::newDevice(INDI::BaseDevice *dp)
 void ClientManager::newProperty(INDI::Property *prop)
 {
     //IDLog("Received new property %s for device %s\n", prop->getName(), prop->getgetDeviceName());
-
-    if (!strcmp (prop->getName(), "EQUATORIAL_EOD_COORD"))
-        emit newTelescope();
-    else if (!strcmp (prop->getName(), "CCD_EXPOSURE"))
-        emit newCCD();
-
     emit newINDIProperty(prop);
 }
 
@@ -127,8 +120,6 @@ void ClientManager::removeProperty(INDI::Property *prop)
     emit removeINDIProperty(prop);
 }
 
-#ifdef INDI_VERSION_MAJOR
-#if (INDI_VERSION_MAJOR >= 1 && INDI_VERSION_MINOR >= 1)
 void ClientManager::removeDevice(INDI::BaseDevice *dp)
 {
     foreach(DriverInfo *driverInfo, managedDrivers)
@@ -152,8 +143,6 @@ void ClientManager::removeDevice(INDI::BaseDevice *dp)
         }
     }
 }
-#endif
-#endif
 
 void ClientManager::newBLOB(IBLOB *bp)
 {
