@@ -15,6 +15,13 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <cmath>
+#include <QStandardPaths>
+#include <QDebug>
+#include <QFile>
+#include <QPen>
+#include <QHttpMultiPart>
+
 #include "cometscomponent.h"
 #include "solarsystemcomposite.h"
 
@@ -27,15 +34,8 @@
 #include "skylabeler.h"
 #include "skypainter.h"
 #include "projections/projector.h"
-
-#include <cmath>
-#include <QStandardPaths>
-#include <QDebug>
-#include <QFile>
-#include <QPen>
-
-#include <KJobUiDelegate>
-#include <KIOCore/KIO/StoredTransferJob>
+#include "auxiliary/filedownloader.h"
+#include "kspaths.h"
 
 CometsComponent::CometsComponent( SolarSystemComposite *parent )
         : SolarSystemListComponent( parent ) {
@@ -112,7 +112,7 @@ void CometsComponent::loadData() {
     sequence.append(qMakePair(QString("H"), KSParser::D_SKIP));
     sequence.append(qMakePair(QString("G"), KSParser::D_SKIP));
 
-    QString file_name = QStandardPaths::locate(QStandardPaths::DataLocation, QString("comets.dat") );
+    QString file_name = KSPaths::locate(QStandardPaths::GenericDataLocation, QString("comets.dat") );
     KSParser cometParser(file_name, '#', sequence);
 
     QHash<QString, QVariant> row_content;
@@ -202,6 +202,10 @@ void CometsComponent::draw( SkyPainter *skyp )
 
 void CometsComponent::updateDataFile()
 {
+    downloadJob = new FileDownloader();
+
+    connect(downloadJob, SIGNAL(downloaded()), this, SLOT(downloadReady()));
+    connect(downloadJob, SIGNAL(error(QString)), this, SLOT(downloadError(QString)));
 
     QUrl url = QUrl( "http://ssd.jpl.nasa.gov/sbdb_query.cgi" );
     QByteArray post_data = QByteArray( "obj_group=all&obj_kind=com&obj_numbere"
@@ -213,31 +217,35 @@ void CometsComponent::updateDataFile()
     "j_kind&.cgifields=obj_group&.cgifields=obj_numbered&.cgifields=combine_mo"
     "de&.cgifields=ast_orbit_class&.cgifields=table_format&.cgifields=ORB_fiel"
     "d_set&.cgifields=OBJ_field_set&.cgifields=preset_field_set&.cgifields=com"
-    "_orbit_class" );
-    QString content_type = "Content-Type: application/x-www-form-urlencoded";
+    "_orbit_class" );    
 
-    // Download file
-    KIO::StoredTransferJob* get_job = KIO::storedHttpPost(post_data,  url);
-    get_job->addMetaData("content-type", content_type );
+    downloadJob->post(url, post_data);
 
-    if( get_job->exec() )
-    {
-        // Comment the first line
-        QByteArray data = get_job->data();
-        data.insert( 0, '#' );
+}
 
-        // Write data to comets.dat
-        QFile file( QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "comets.dat" ) ;
-        file.open( QIODevice::WriteOnly|QIODevice::Truncate|QIODevice::Text );
-        file.write( data );
-        file.close();
+void CometsComponent::downloadReady()
+{
+    // Comment the first line
+    QByteArray data = downloadJob->downloadedData();
+    data.insert( 0, '#' );
 
-        // Reload comets
-        loadData();
+    // Write data to asteroids.dat
+    QFile file( KSPaths::writableLocation(QStandardPaths::GenericDataLocation) + "comets.dat" ) ;
+    file.open( QIODevice::WriteOnly|QIODevice::Truncate|QIODevice::Text );
+    file.write( data );
+    file.close();
 
-        KStars::Instance()->data()->setFullTimeUpdate();
-    } else
-    {
-        get_job->uiDelegate()->showErrorMessage();
-    }
+    // Reload asteroids
+    loadData();
+
+    KStars::Instance()->data()->setFullTimeUpdate();
+
+    downloadJob->deleteLater();
+}
+
+void CometsComponent::downloadError(const QString &errorString)
+{
+    KMessageBox::error(0, i18n("Error downloading comets data: %1", errorString));
+
+    downloadJob->deleteLater();
 }
