@@ -21,7 +21,7 @@
 #include <qimage.h>
 #include <qpoint.h>
 
-#include "kstars/skyobjects/skyobject.h"
+#include "skyobject.h"
 #include "dms.h"
 
 class QImage;
@@ -74,7 +74,7 @@ public:
 
     virtual DeepSkyObject* clone() const;
     virtual SkyObject::UID getUID() const;
-    
+
     /** *Destructor */
     virtual ~DeepSkyObject() { }
 
